@@ -1,4 +1,5 @@
 import numpy as np
+from tabulate import tabulate
 from typing import List, Dict, Any
 
 class QueryResult:
@@ -28,6 +29,9 @@ class QueryResult:
 
         return f'{header_str}\n{records_str}'
 
+    def format_as_table(self) -> str:
+        return tabulate(self.records, headers=self.result_cols, tablefmt='fancy_grid')
+
     def save_to_file(self, filepath: str):
         """
         Saves query reslt as a CSV
