@@ -7,14 +7,14 @@ src_path = os.path.join(os.getcwd(), 'src')
 sys.path.append(src_path)
 
 # add sample data dir to path
-sample_data_path = os.path.join(os.getcwd(), 'sample_data')
+sample_data_path = os.path.join(os.getcwd(), 'example')
 sys.path.append(sample_data_path)
 
 from filequery.filedb import FileDb
 
 class TestFileQuery(unittest.TestCase):
     def test_exec_query(self):
-        fdb = FileDb('sample_data/test.csv')
+        fdb = FileDb('example/test.csv')
         res = fdb.exec_query('select * from test')
         
         self.assertEqual(len(res.records), 3)
@@ -26,7 +26,7 @@ if __name__ == '__main__':
     unittest.main()
     
     # for one-off testing
-    # fdb = FileDb('sample_data/test.csv')
+    # fdb = FileDb('example/test.csv')
     # res = fdb.exec_query('select * from test')
     
     # print(res)
